@@ -21,54 +21,50 @@ class SleeperLeagueLoader(LeagueLoader):
     """
     __INVALID_SLEEPER_LEAGUE_IDS = [None, "0"]
 
-    @classmethod
-    def __initializeClassVariables(cls) -> None:
-        cls.__sleeperUserIdToOwnerMap: dict[int, Owner] = dict()
-        cls.__sleeperRosterIdToTeamMap: dict[str, Team] = dict()
+    def __init__(self, mostRecentLeagueId: str, **kwargs):
+        super().__init__(mostRecentLeagueId, **kwargs)
 
-    @classmethod
-    def loadLeague(cls, mostRecentLeagueId: str, **kwargs) -> League:
-        cls.__initializeClassVariables()
+        self.__sleeperUserIdToOwnerMap: dict[str, Owner] = dict()
+        self.__sleeperRosterIdToTeamMap: dict[int, Team] = dict()
+
+    def loadLeague(self) -> League:
         # get all leagues
-        mostRecentLeague: SleeperLeague = LeagueAPIClient.get_league(league_id=mostRecentLeagueId)
+        mostRecentLeague: SleeperLeague = LeagueAPIClient.get_league(league_id=self._leagueId)
         sleeperLeagues = [mostRecentLeague]
         previousLeagueId = mostRecentLeague.previous_league_id
-        while previousLeagueId not in cls.__INVALID_SLEEPER_LEAGUE_IDS:
+        while previousLeagueId not in self.__INVALID_SLEEPER_LEAGUE_IDS:
             previousLeague = LeagueAPIClient.get_league(league_id=previousLeagueId)
             sleeperLeagues.append(previousLeague)
             previousLeagueId = previousLeague.previous_league_id
         # reverse list so most recent is last in list
         sleeperLeagues = sleeperLeagues[::-1]
-        return cls.__buildLeague(sleeperLeagues)
+        return self.__buildLeague(sleeperLeagues)
 
-    @classmethod
-    def __buildLeague(cls, sleeperLeagues: list[SleeperLeague]) -> League:
+    def __buildLeague(self, sleeperLeagues: list[SleeperLeague]) -> League:
         years = list()
         leagueName = None
-        cls.__loadOwners(sleeperLeagues)
-        owners = list(cls.__sleeperUserIdToOwnerMap.values())
+        self.__loadOwners(sleeperLeagues)
+        owners = list(self.__sleeperUserIdToOwnerMap.values())
         for sleeperLeague in sleeperLeagues:
             leagueName = sleeperLeague.name if leagueName is None else leagueName
-            year = cls.__buildYear(sleeperLeague)
+            year = self.__buildYear(sleeperLeague)
             if len(year.weeks) > 0:
                 years.append(year)
         return League(name=leagueName, owners=owners, years=years)
 
-    @classmethod
-    def __buildYear(cls, sleeperLeague: SleeperLeague) -> Year:
-        teams = cls.__buildTeams(sleeperLeague)
-        weeks = cls.__buildWeeks(sleeperLeague)
+    def __buildYear(self, sleeperLeague: SleeperLeague) -> Year:
+        teams = self.__buildTeams(sleeperLeague)
+        weeks = self.__buildWeeks(sleeperLeague)
         return Year(yearNumber=int(sleeperLeague.season), teams=teams, weeks=weeks)
 
-    @classmethod
-    def __buildWeeks(cls, sleeperLeague: SleeperLeague) -> list[Week]:
+    def __buildWeeks(self, sleeperLeague: SleeperLeague) -> list[Week]:
         weeks = list()
         # get regular season weeks
         for i in range(sleeperLeague.settings.playoff_week_start):
             # get each teams matchup for that week
             matchups = list()
             sleeperMatchups = LeagueAPIClient.get_matchups_for_week(league_id=sleeperLeague.league_id, week=i + 1)
-            if cls.__isCompletedWeek(sleeperMatchups):
+            if self.__isCompletedWeek(sleeperMatchups):
                 sleeperMatchupIdToSleeperMatchupMap: dict[int, list[SleeperMatchup]] = dict()
                 for sleeperMatchup in sleeperMatchups:
                     if sleeperMatchup.matchup_id in sleeperMatchupIdToSleeperMatchupMap.keys():
@@ -79,11 +75,11 @@ class SleeperLeagueLoader(LeagueLoader):
                 for sleeperMatchupPair in sleeperMatchupIdToSleeperMatchupMap.values():
                     # team A
                     teamASleeperMatchup = sleeperMatchupPair[0]
-                    teamA = cls.__sleeperRosterIdToTeamMap[teamASleeperMatchup.roster_id]
+                    teamA = self.__sleeperRosterIdToTeamMap[teamASleeperMatchup.roster_id]
 
                     # team B
                     teamBSleeperMatchup = sleeperMatchupPair[1]
-                    teamB = cls.__sleeperRosterIdToTeamMap[teamBSleeperMatchup.roster_id]
+                    teamB = self.__sleeperRosterIdToTeamMap[teamBSleeperMatchup.roster_id]
 
                     matchups.append(Matchup(teamAId=teamA.id,
                                             teamBId=teamB.id,
@@ -109,7 +105,7 @@ class SleeperLeagueLoader(LeagueLoader):
             # get each teams matchup for that week
             matchups = list()
             sleeperMatchups = LeagueAPIClient.get_matchups_for_week(league_id=sleeperLeague.league_id, week=weekNumber)
-            if cls.__isCompletedWeek(sleeperMatchups):
+            if self.__isCompletedWeek(sleeperMatchups):
                 # sort matchups by roster IDs
                 rosterIdToSleeperMatchupMap: dict[int, SleeperMatchup] = dict()
                 for sleeperMatchup in sleeperMatchups:
@@ -118,12 +114,12 @@ class SleeperLeagueLoader(LeagueLoader):
                 for sleeperPlayoffMatchup in playoffRoundAndSleeperPlayoffMatchups[i]:
                     # team A
                     teamARosterId = sleeperPlayoffMatchup.team_1_roster_id
-                    teamA = cls.__sleeperRosterIdToTeamMap[teamARosterId]
+                    teamA = self.__sleeperRosterIdToTeamMap[teamARosterId]
                     teamAPoints = rosterIdToSleeperMatchupMap[teamARosterId].points
                     teamAHasTiebreaker = sleeperPlayoffMatchup.winning_roster_id == sleeperPlayoffMatchup.team_1_roster_id
                     # team B
                     teamBRosterId = sleeperPlayoffMatchup.team_2_roster_id
-                    teamB = cls.__sleeperRosterIdToTeamMap[teamBRosterId]
+                    teamB = self.__sleeperRosterIdToTeamMap[teamBRosterId]
                     teamBPoints = rosterIdToSleeperMatchupMap[teamBRosterId].points
                     teamBHasTiebreaker = sleeperPlayoffMatchup.winning_roster_id == sleeperPlayoffMatchup.team_2_roster_id
                     # determine if this is a championship matchup or not
@@ -141,13 +137,12 @@ class SleeperLeagueLoader(LeagueLoader):
 
         return weeks
 
-    @classmethod
-    def __isCompletedWeek(cls, sleeperMatchups: list[SleeperMatchup]) -> bool:
+    @staticmethod
+    def __isCompletedWeek(sleeperMatchups: list[SleeperMatchup]) -> bool:
         # there might be a better way of determining this
         return sum([sleeperMatchup.points for sleeperMatchup in sleeperMatchups]) != 0
 
-    @classmethod
-    def __buildTeams(cls, sleeperLeague: SleeperLeague) -> list[Team]:
+    def __buildTeams(self, sleeperLeague: SleeperLeague) -> list[Team]:
         teams = list()
         sleeperUsers = LeagueAPIClient.get_users_in_league(league_id=sleeperLeague.league_id)
         sleeperRosters = LeagueAPIClient.get_rosters(league_id=sleeperLeague.league_id)
@@ -160,26 +155,18 @@ class SleeperLeagueLoader(LeagueLoader):
             if rosterId is None:
                 raise DoesNotExistException(
                     f"No Roster ID match found for Sleeper User with ID: '{sleeperUser.user_id}'.")
-            owner = cls.__sleeperUserIdToOwnerMap[sleeperUser.user_id]
+            owner = self.__sleeperUserIdToOwnerMap[sleeperUser.user_id]
             teamName = sleeperUser.display_name
             # if we can find a team name for this user, use it instead of their display name
             if isinstance(sleeperUser.metadata, dict) and "team_name" in sleeperUser.metadata.keys():
                 teamName = sleeperUser.metadata["team_name"]
             team = Team(ownerId=owner.id, name=teamName)
             teams.append(team)
-            cls.__sleeperRosterIdToTeamMap[rosterId] = team
+            self.__sleeperRosterIdToTeamMap[rosterId] = team
         return teams
 
-    @classmethod
-    def __loadOwners(cls, sleeperLeagues: list[SleeperLeague]) -> None:
+    def __loadOwners(self, sleeperLeagues: list[SleeperLeague]) -> None:
         for sleeperLeague in sleeperLeagues:
             sleeperUsers = LeagueAPIClient.get_users_in_league(league_id=sleeperLeague.league_id)
             for sleeperUser in sleeperUsers:
-                cls.__sleeperUserIdToOwnerMap[sleeperUser.user_id] = Owner(name=sleeperUser.display_name)
-
-    @classmethod
-    def __loadRosters(cls, sleeperLeagues: list[SleeperLeague]) -> None:
-        for sleeperLeague in sleeperLeagues:
-            sleeperRosters = LeagueAPIClient.get_rosters(league_id=sleeperLeague.league_id)
-            for sleeperRoster in sleeperRosters:
-                cls.__sleeperRosterIdToSleeperOwnerIdMap[sleeperRoster.roster_id] = sleeperRoster.owner_id
+                self.__sleeperUserIdToOwnerMap[sleeperUser.user_id] = Owner(name=sleeperUser.display_name)
